#include <GL/gl.h>

#include "../misc/Random.h"
#include "../misc/Theme.h"
#include "../engine/GLTexture.h"
#include "Cloud.h"

/*************************************************/

Cloud::Cloud(Theme *_theme, int _typeNr, bool offRight)
	: Entity(0.0, 0.0), theme(_theme), typeNr(_typeNr)
{
	aliveFlag = true;
	
	width		= theme->getCloudType(typeNr).width;
	height	= theme->getCloudType(typeNr).height;
	
	if (offRight)
		setX(801.0);
	else
		setX(randomFloat(-width, 800.0));
	
	double minTop = theme->getCloudsTop();
	double maxBottom = theme->getCloudsBottom();
	setY(randomFloat(minTop, maxBottom - height));
	
	vx = randomFloat(-0.02, -0.05);
}

/*************************************************/

void Cloud::step(double dt)
{
	x += vx * dt;
	
	if (x < -width)
		aliveFlag = false;
}

/*************************************************/

void Cloud::render()
{
	glPushAttrib(GL_COLOR_BUFFER_BIT | GL_ENABLE_BIT | GL_TEXTURE_BIT);
	
	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
	glEnable(GL_TEXTURE_2D);
	glEnable(GL_BLEND);
	glColor4f(1.0, 1.0, 1.0, 1.0);
	
	CloudType ct = theme->getCloudType(typeNr);
	
	ct.texture->bind();
	glBegin(GL_QUADS);
		glTexCoord2f(0.0, 0.0); glVertex2f(x, y);
		glTexCoord2f(1.0, 0.0); glVertex2f(x + width, y);
		glTexCoord2f(1.0, 1.0); glVertex2f(x + width, y + height);
		glTexCoord2f(0.0, 1.0); glVertex2f(x, y + height);
	glEnd();
	
	glPopAttrib();
}
