#ifndef _TANK_H
#define _TANK_H

#include "../Classes.h"

#include "../entity/Entity.h"
#include "../engine/GLColor.h"
#include "../engine/GLBitmap.h"
#include "../engine/TextRenderer.h"

/***********************************/

enum TankState{TS_IDLE, TS_SHOOTING, TS_COOLDOWN, TS_SLOW_SHOOTING};

class Tank :
	public Entity
{
	private:
		
		static int count;
		static GLBitmap *bodyBMP, *gunBMP, *crosshairBMP;
		
		GLColor color, shieldColor, smokeColor;
	
		double health;

		int		state;
		double	cooldownCounter;
		double	gunAngle, gunPower;
		int		gunDirection;
	
		bool		invincible;
	
		TankControl *controller;
	
	public:
		
		Tank(GLColor color, double x, double y);
		~Tank();

		void			setController(TankControl *control) {controller = control;};
		TankControl*	getController() {return controller;};
		
		int		type() {return ETYPE_TANK;};
		
		double	getPower() {return gunPower;};
		double	getAngle() {return gunAngle;};
		int		getState() {return state;};
		
		int		collisionPriority() {return 10;};
		int		stepPriority()   {return 50;};
		int		renderPriority() {return 50;};
		bool		isAlive() {return (health > 0.0);};
		
		bool		isArea() {return true;};
		bool		contains(double x, double y);
		
		bool		isDamagable() {return true;};
		void		doDamage(double dmg);
		void		setInvincible(bool _invincible) {invincible = _invincible;};
		
		void		render();
		void		step(double dt);
};

/***********************************/

#endif
